package md

import "applet/app/db/model"

type EnterpriseAddReq struct {
	Name      string `json:"name" binding:"required" label:"名称"`
	Pvd       int32  `json:"pvd" label:"场景"`
	Kind      int32  `json:"kind" binding:"required" label:"种类(1:央厨-学校 2:央厨-工厂 3:自营-学校 4:自营-工厂 5:养老院)"`
	CompanyId int    `json:"company_id" binding:"required" label:"所属公司id"`
	Memo      string `json:"memo" label:"备注"`
}

type EnterpriseUpdateReq struct {
	Id         int    `json:"id" binding:"required" label:"企业id"`
	Name       string `json:"name" binding:"required" label:"名称"`
	Pvd        int32  `json:"pvd" label:"场景"`
	Kind       int32  `json:"kind" binding:"required" label:"种类(1:央厨-学校 2:央厨-工厂 3:自营-学校 4:自营-工厂 5:养老院)"`
	CompanyId  int    `json:"company_id" binding:"required" label:"所属公司id"`
	Memo       string `json:"memo" label:"备注"`
	State      int32  `json:"state" label:"状态"`
	PeriodList []struct {
		Id        int    `json:"id" label:"学段id"`
		Name      string `json:"name" label:"名称"`
		GradeList []struct {
			Id        int    `json:"id" label:"年级id"`
			Name      string `json:"name" label:"名称"`
			ClassList []struct {
				Id   int    `json:"id" label:"班级id"`
				Name string `json:"name" label:"名称"`
			} `json:"class_list" label:"班级"`
		} `json:"grade_list" label:"年级"`
	} `json:"period_list" label:"学段"`
}

type EnterpriseDeleteReq struct {
	EnterpriseIds []int `json:"enterprise_ids"`
}

type EnterpriseUpdateStateReq struct {
	Id    int   `json:"id" binding:"required" label:"企业id"`
	State int32 `json:"state" label:"状态"`
}

type EnterpriseListReq struct {
	Limit int    `json:"limit"`
	Page  int    `json:"page" `
	Name  string `json:"name" label:"名称"`
	Kind  int    `json:"kind" label:"种类"`
}

type EnterpriseDetailResp struct {
	Enterprise model.Enterprise   `json:"enterprise"`
	PeriodList []PeriodListStruct `json:"period_list"`
}

type PeriodListStruct struct {
	Period    model.Period      `json:"period"`
	GradeList []GradeListStruct `json:"grade_list"`
}

type GradeListStruct struct {
	Grade     model.Grade   `json:"grade"`
	ClassList []model.Class `json:"class_list"`
}

type SetCentralKitchenForSchoolWithSpecForSystemReq struct {
	BreakfastUnitPrice           string `json:"breakfast_unit_price" binding:"required" label:"早餐-单价"`
	BreakfastUnitPriceForTeacher string `json:"breakfast_unit_price_for_teacher" binding:"required" label:"教师-早餐-单价"`
	LunchUnitPrice               string `json:"lunch_unit_price" binding:"required" label:"午餐-单价"`
	LunchUnitPriceForTeacher     string `json:"lunch_unit_price_for_teacher" binding:"required" label:"教师-午餐-单价"`
	DinnerUnitPrice              string `json:"dinner_unit_price" binding:"required" label:"晚餐-单价"`
	DinnerUnitPriceForTeacher    string `json:"dinner_unit_price_for_teacher" binding:"required" label:"教师-晚餐-单价"`
}

type ListCentralKitchenForSchoolPackageForSystemReq struct {
	Page  int    `json:"page" label:"页码"`
	Limit int    `json:"limit" label:"每页数量"`
	Year  string `json:"year" label:"年份"`
	Month string `json:"month" label:"月份"`
}

type SaveCentralKitchenForSchoolPackageForSystemReq struct {
	Id        int    `json:"id" label:"套餐ID"`
	Year      string `json:"year" binding:"required" label:"年份"`
	Month     string `json:"month" binding:"required" label:"月份"`
	StartDate string `json:"start_date" binding:"required" label:"开始时间"`
	EndDate   string `json:"end_date" binding:"required" label:"截止时间"`
	State     int    `json:"state" label:"状态(1:可用 2:不可用)"`
	DateList  []struct {
		Date            string `json:"date"`
		IsOpenBreakfast int    `json:"is_open_breakfast"`
		IsOpenLunch     int    `json:"is_open_lunch"`
		IsOpenDinner    int    `json:"is_open_dinner"`
		IsOpenReplenish int    `json:"is_open_replenish"`
	} `json:"date_list" binding:"required" label:"日期"`
}

type SyncCentralKitchenForSchoolPackageForSystemReq struct {
	Ids                 []int `json:"ids" label:"套餐ids"`
	EnterpriseIds       []int `json:"enterprise_ids" label:"校企ids"`
	IsCarryPackagePrice bool  `json:"is_carry_package_price" label:"是否跟随套餐价格"`
}

type CentralKitchenForSchoolPackageForSystemWithDay struct {
	Date            string `json:"date"`
	IsOpenBreakfast int    `json:"is_open_breakfast"`
	IsOpenLunch     int    `json:"is_open_lunch"`
	IsOpenDinner    int    `json:"is_open_dinner"`
	IsOpenReplenish int    `json:"is_open_replenish"`
}
